@@ -288,8 +288,15 @@ def date_string_handler(date_string: str) -> datetime:
     Returns:
         datetime: datetime value
     """
-    if re.search(r"\d{4}\-\d{2}\-\d{2}", str(date_string).strip()):
-        return datetime.strptime(str(date_string).strip(), "%Y-%m-%d")
+    date_string = str(date_string).strip()
+    string_search = re.search(r"\d{4}\-\d{2}\-\d{2}", date_string)
+    if string_search:
+        date_part = string_search.group()
+        return datetime.strptime(date_part, "%Y-%m-%d")
+    if date_string == "tomorrow":
+        return datetime.strptime(
+            (datetime.now() + timedelta(days=1)).date().isoformat(), "%Y-%m-%d"
+        )
     phrase_handler = PastDatePhraseHandler(date_value=date_string)
     cadence, time_bucket = phrase_handler.phrase_to_date()
     handler = DateHandlerFactory().get_date_handler(
