@@ -113,7 +113,7 @@ class ChannelIdsV2(RequestHandler):
         print("GET v2: channel ids.")
         endpoint_url = f"channels?apikey={self._creds['api_key']}"
         url = f"{self.base_url}{endpoint_url}"
-        response = self.session.get(url=url)
+        response = self.session.get(url=url, params={"limit": "9999"})
 
         response_data = response.json()
         if response.status_code == 200:
@@ -156,10 +156,15 @@ class ContentIdByChannelId(RequestHandler):
             for item in response_data.get("items"):
                 content_id = item.get("id")
                 channel_id = item.get("channels")
-                if channel_id is not None and channel_id[0] in channel_ids:
-                    content_ids_by_channel_id.setdefault(channel_id[0], []).append(
-                        content_id
-                    )
+                if channel_id is not None:
+                    channel_id = channel_id[0]
+                    if network == "linkedIn":
+                        channel_id = channel_id.replace("-", "")
+
+                    if channel_id in channel_ids:
+                        content_ids_by_channel_id.setdefault(channel_id, []).append(
+                            content_id
+                        )
             endpoint_url = response_data.get("next", {"href": None}).get("href")
         return content_ids_by_channel_id
 
@@ -336,7 +341,7 @@ class ContentInsights(FalconAPICall):
     """This class  gets content insights and normalises the data"""
 
     @staticmethod
-    def _normalize_data(dataset: dict, network: str, channel_ids: dict)-> List[Dict]:
+    def _normalize_data(dataset: dict, network: str, channel_ids: dict) -> List[Dict]:
         temp = {}
 
         for metric, data_items in dataset.items():
@@ -418,7 +423,7 @@ class ChannelInsights(FalconAPICall):
     """This class  gets channel insights and normalises the data"""
 
     @staticmethod
-    def _normalize_data(dataset: dict, network: str, channel_ids: dict)-> List[Dict]:
+    def _normalize_data(dataset: dict, network: str, channel_ids: dict) -> List[Dict]:
         templist = []
 
         for metric, data_items in dataset.items():
