@@ -13,13 +13,11 @@ class CustomGBQReader:
     Custom Google BigQuery Console Reader
     """
 
-    def __init__(self, service_account_secrets_path=None, config_path=None):
+    def __init__(self, creds_filepath=None, config_path=None):
 
-        if service_account_secrets_path is not None:
-            self.credentials = load_file(service_account_secrets_path, fmt="json")
+        self.credentials = load_file(creds_filepath, fmt="json")
 
-        if config_path is not None:
-            self.config = load_file(config_path, fmt="yml")
+        self.config = load_file(config_path, fmt="yml")
 
     def get_auth(self):
         """
@@ -35,10 +33,9 @@ class CustomGBQReader:
         )
         return client
 
-    def build_query(self, query, date_run):
+    def build_query(self, date_run):
         """Build up query """
         # initialization
-        query = ""
         project_id: str = self.credentials["project_id"]
         table_id: str = self.credentials["table"]
         query_prefix = f"SELECT *, NULL FROM {project_id}.{table_id}.events_{date_run} "
@@ -46,7 +43,8 @@ class CustomGBQReader:
         query = query_prefix + query_suffix
         return query
 
-    def _query_handler(self, client, query, params=None):
+    @staticmethod
+    def _query_handler(client, query, params=None):
         """Query handler for the dataset"""
 
         result = None
@@ -74,7 +72,6 @@ class CustomGBQReader:
         Consumes a config file and loops through the dims
         to return relevant data from Google Big Query.
         """
-        _query = None
         client = self.get_auth()
 
         start_date: str = self.config["start_date"]
@@ -83,15 +80,17 @@ class CustomGBQReader:
         print(f"Gathering data between given dates {start_date} and {end_date}. ")
         # split request by date to reduce 504 errors
         # BigQuery tables are named in format (project_id)_name_YYYYMMDD
+
         for firebase_id in self.config["firebase_ids"]:
             params = [
-            bigquery.ScalarQueryParameter("firebase_id", "STRING", firebase_id),
+                bigquery.ScalarQueryParameter("firebase_id", "STRING", firebase_id),
             ]
             business = self.config["firebase_ids"][firebase_id]
 
             for date in date_range(start_date=start_date, end_date=end_date):
+
                 current_date = date.replace("-", "")
-                query = self.build_query(_query, current_date)
+                query = self.build_query(current_date)
 
                 print(f"Querying at date: {current_date}.")
                 # run until none is returned or there is no more data in rows
@@ -100,6 +99,6 @@ class CustomGBQReader:
 
                 yield {
                     "date": date,
-                    "business" : business,
+                    "business": business,
                     "data": result,
                 }
